@@ -51,7 +51,7 @@ class Trainer(PLTrainer):
         limit_predict_batches: Union[int, float] = 1.0,
         val_check_interval: Union[int, float] = 1.0,
         flush_logs_every_n_steps: int = 100,
-        log_every_n_steps: int = 50,
+        log_every_n_steps: int = 0,
         accelerator: Optional[Union[str, Accelerator]] = None,
         sync_batchnorm: bool = False,
         precision: int = 32,
@@ -124,6 +124,10 @@ class Trainer(PLTrainer):
             version=os.path.join(log_name, "val"), log_graph=False
         ) if self.has_no_logger is not None else None
 
+        self.log_every_n_steps = log_every_n_steps
+        self.log_on_epoch = log_every_n_steps == 0
+        self.log_on_step = log_every_n_steps > 0
+
     @staticmethod
     def build(
         logger: Optional[str],
