@@ -1,6 +1,7 @@
 from .func import reduce_dict_by, summarize_dict_by, generate_inf_seq, compose, listdir, with_printed, \
     with_printed_shape, is_bad_num, ifelse
 from .type import ModuleFactory, Shape, Device
+from .configuration import Configuration
 
 
 __all__ = [
@@ -15,5 +16,6 @@ __all__ = [
     "ifelse",
     "ModuleFactory",
     "Shape",
-    "Device"
+    "Device",
+    "Configuration"
 ]
\ No newline at end of file
